Learn R Programming

forestly (version 0.1.2)

forestly_adsl_3grp: A subject level demographic dataset

Description

A dataset containing the demographic information of a clinical trial following the CDISC ADaM standard.

Usage

forestly_adsl_3grp

Arguments

Format

A data frame with 254 rows and 49 variables.

Details

Definition of each variable can be found at https://github.com/phuse-org/phuse-scripts/tree/master/data/adam/cdisc.